Full-pol data format — PolSARtools 0.10 documentation

Skip to main content
`Ctrl`+`K`

# Full-pol data format

The package supports full polarimetric SAR data in the following matrix representations:

- S2 (Scattering matrix)

- C3 / C4 (Covariance matrix)

- T3 / T4 (Coherency matrix)

Each format can be provided as .tif or .bin/ .hdr files with associated metadata.

## S2 – Scattering Matrix

Note: All elements of the scattering matrix are in complex data type.

Element | .bin/.hdr Files | .tif Files
--- | --- | ---
S_HH | s11.bin/.hdr | s11.tif
S_HV | s12.bin/.hdr | s12.tif
S_VH | s21.bin/.hdr | s21.tif
S_VV | s22.bin/.hdr | s22.tif

## C3 / C4 – Covariance Matrix

Note: All elements of the covariance matrix are stored as float values. Complex-valued entries are separated into real and imaginary components. C4 includes additional terms compared to C3.

Element | .bin/.hdr Files | .tif Files
--- | --- | ---
C11 | C11.bin / C11.hdr | C11.tif
C12 (Real) | C12_real.bin / .hdr | C12_real.tif
C12 (Imag) | C12_imag.bin / .hdr | C12_imag.tif
C13 (Real) | C13_real.bin / .hdr | C13_real.tif
C13 (Imag) | C13_imag.bin / .hdr | C13_imag.tif
C14 (Real)* | C14_real.bin / .hdr | C14_real.tif
C14 (Imag)* | C14_imag.bin / .hdr | C14_imag.tif
C22 | C22.bin / C22.hdr | C22.tif
C23 (Real) | C23_real.bin / .hdr | C23_real.tif
C23 (Imag) | C23_imag.bin / .hdr | C23_imag.tif
C24 (Real)* | C24_real.bin / .hdr | C24_real.tif
C24 (Imag)* | C24_imag.bin / .hdr | C24_imag.tif
C33 | C33.bin / C33.hdr | C33.tif
C34 (Real)* | C34_real.bin / .hdr | C34_real.tif
C34 (Imag)* | C34_imag.bin / .hdr | C34_imag.tif
C44* | C44.bin / C44.hdr | C44.tif

* Only applicable to C4 (4x4 covariance matrix).

## T3 / T4 – Coherency Matrix

Note: All elements of the coherency matrix are stored as float values (real and imaginary parts separated for complex entries).

Element | .bin/.hdr Files | .tif Files
--- | --- | ---
T11 | T11.bin / T11.hdr | T11.tif
T12 (Real) | T12_real.bin / .hdr | T12_real.tif
T12 (Imag) | T12_imag.bin / .hdr | T12_imag.tif
T13 (Real) | T13_real.bin / .hdr | T13_real.tif
T13 (Imag) | T13_imag.bin / .hdr | T13_imag.tif
T14 (Real)* | T14_real.bin / .hdr | T14_real.tif
T14 (Imag)* | T14_imag.bin / .hdr | T14_imag.tif
T22 | T22.bin / T22.hdr | T22.tif
T23 (Real) | T23_real.bin / .hdr | T23_real.tif
T23 (Imag) | T23_imag.bin / .hdr | T23_imag.tif
T24 (Real)* | T24_real.bin / .hdr | T24_real.tif
T24 (Imag)* | T24_imag.bin / .hdr | T24_imag.tif
T33 | T33.bin / T33.hdr | T33.tif
T34 (Real)* | T34_real.bin / .hdr | T34_real.tif
T34 (Imag)* | T34_imag.bin / .hdr | T34_imag.tif
T44* | T44.bin / T44.hdr | T44.tif

* Only applicable to T4 (4x4 coherency matrix).

## Matrix Compatibility Overview

Format | Description | Supported File Types
--- | --- | ---
S2 | 2x2 Scattering matrix | .bin/.hdr, .tif
C3 | 3x3 Covariance matrix | .bin/.hdr, .tif
C4 | 4x4 Covariance matrix | .bin/.hdr, .tif
T3 | 3x3 Coherency matrix | .bin/.hdr, .tif
T4 | 4x4 Coherency matrix | .bin/.hdr, .tif